deprecated-matrixCorr: Deprecated Compatibility Wrappers

deprecated-matrixCorrR Documentation

Deprecated Compatibility Wrappers

Description

Temporary wrappers for functions renamed in matrixCorr 1.0.0. These wrappers preserve the pre-1.0 entry points while warning that they will be removed in 2.0.0.

Usage

bland_altman(
  group1,
  group2,
  two = 1.96,
  mode = 1L,
  conf_level = 0.95,
  n_threads = getOption("matrixCorr.threads", 1L),
  verbose = FALSE
)

bland_altman_repeated(
  data = NULL,
  response,
  subject,
  method,
  time,
  two = 1.96,
  conf_level = 0.95,
  n_threads = getOption("matrixCorr.threads", 1L),
  include_slope = FALSE,
  use_ar1 = FALSE,
  ar1_rho = NA_real_,
  max_iter = 200L,
  tol = 1e-06,
  verbose = FALSE
)

biweight_mid_corr(
  data,
  c_const = 9,
  max_p_outliers = 1,
  pearson_fallback = c("hybrid", "none", "all"),
  na_method = c("error", "pairwise"),
  mad_consistent = FALSE,
  w = NULL,
  sparse_threshold = NULL,
  n_threads = getOption("matrixCorr.threads", 1L),
  output = c("matrix", "sparse", "edge_list"),
  threshold = 0,
  diag = TRUE
)

distance_corr(data, na_method = c("error", "pairwise"), ...)

partial_correlation(
  data,
  method = c("oas", "ridge", "sample"),
  lambda = 0.001,
  return_cov_precision = FALSE,
  ci = FALSE,
  conf_level = 0.95,
  output = c("matrix", "sparse", "edge_list"),
  threshold = 0,
  diag = TRUE
)

ccc_lmm_reml(
  data,
  response,
  rind,
  method = NULL,
  time = NULL,
  interaction = FALSE,
  max_iter = 100,
  tol = 1e-06,
  Dmat = NULL,
  Dmat_type = c("time-avg", "typical-visit", "weighted-avg", "weighted-sq"),
  Dmat_weights = NULL,
  Dmat_rescale = TRUE,
  ci = FALSE,
  conf_level = 0.95,
  ci_mode = c("auto", "raw", "logit"),
  verbose = FALSE,
  digits = 4,
  use_message = TRUE,
  ar = c("none", "ar1"),
  ar_rho = NA_real_,
  slope = c("none", "subject", "method", "custom"),
  slope_var = NULL,
  slope_Z = NULL,
  drop_zero_cols = TRUE,
  vc_select = c("auto", "none"),
  vc_alpha = 0.05,
  vc_test_order = c("subj_time", "subj_method"),
  include_subj_method = NULL,
  include_subj_time = NULL,
  sb_zero_tol = 1e-10
)

ccc_pairwise_u_stat(
  data,
  response,
  method,
  subject,
  time = NULL,
  Dmat = NULL,
  delta = 1,
  ci = FALSE,
  conf_level = 0.95,
  n_threads = getOption("matrixCorr.threads", 1L),
  verbose = FALSE
)

Arguments

group1, group2

Numeric vectors of equal length.

two

Positive scalar; the multiple of the standard deviation used to define the limits of agreement.

mode

Integer; 1 uses group1 - group2, 2 uses group2 - group1.

conf_level

Confidence level.

n_threads

Integer number of OpenMP threads.

verbose

Logical; print brief progress or diagnostic output.

data

A data.frame, matrix, or repeated-measures dataset accepted by the corresponding replacement function.

response

Numeric response vector or column name, depending on the target method.

subject

Subject identifier or subject column name.

method

Method label or method column name.

time

Replicate/time index or time column name.

include_slope

Logical; whether to estimate proportional bias.

use_ar1

Logical; whether to use AR(1) within-subject correlation.

ar1_rho

AR(1) parameter.

max_iter, tol

EM control parameters.

c_const

Positive numeric Tukey biweight tuning constant.

max_p_outliers

Numeric in ⁠(0, 1]⁠; optional cap on the maximum proportion of outliers on each side.

pearson_fallback

Character fallback policy used by bicor().

na_method

Missing-data policy forwarded to the replacement function when supported.

mad_consistent

Logical; if TRUE, uses the consistency-corrected MAD.

w

Optional vector of case weights.

sparse_threshold

Optional threshold controlling sparse output.

output

Output representation for the computed estimates.

threshold

Non-negative absolute-value filter for non-matrix outputs.

diag

Logical; whether to include diagonal entries in non-matrix outputs.

...

Additional arguments forwarded to the replacement function when supported.

lambda

Numeric regularisation strength used by pcorr().

return_cov_precision

Logical; if TRUE, also return covariance and precision matrices.

ci

Logical; if TRUE, request confidence intervals when supported by the replacement function.

rind

Character; column identifying subjects, forwarded as subject to ccc_rm_reml().

interaction

Logical; forwarded to ccc_rm_reml().

Dmat

Optional distance matrix forwarded to ccc_rm_reml().

Dmat_type

Character selector controlling how Dmat is constructed.

Dmat_weights

Optional weights used when Dmat_type requires them.

Dmat_rescale

Logical; whether to rescale Dmat.

ci_mode

Character selector for the confidence-interval scale used by ccc_rm_reml().

digits

Display precision forwarded to ccc_rm_reml().

use_message

Logical; whether the deprecated wrapper emits a lifecycle message.

ar

Character selector for the within-subject residual correlation model.

ar_rho

Numeric AR(1) parameter.

slope

Character selector for the proportional-bias slope structure.

slope_var

Optional covariance matrix for custom slopes.

slope_Z

Optional design matrix for custom slopes.

drop_zero_cols

Logical; whether zero-variance design columns are dropped.

vc_select

Character selector controlling variance-component selection.

vc_alpha

Significance level used in variance-component selection.

vc_test_order

Character vector controlling the variance-component test order.

include_subj_method

Optional logical override for the subject-by-method component.

include_subj_time

Optional logical override for the subject-by-time component.

sb_zero_tol

Numerical tolerance used when stabilising the scale-bias term.

delta

Numeric power exponent for U-statistics distances.

Details

Renamed functions:

  • bland_altman() -> ba()

  • bland_altman_repeated() -> ba_rm()

  • biweight_mid_corr() -> bicor()

  • distance_corr() -> dcor()

  • partial_correlation() -> pcorr()

  • ccc_lmm_reml() -> ccc_rm_reml()

  • ccc_pairwise_u_stat() -> ccc_rm_ustat()

The deprecated wrappers will be removed in matrixCorr 2.0.0.


matrixCorr documentation built on April 18, 2026, 5:06 p.m.